@@ -81,331 +81,68 @@ grm_iif <- function(theta, a, b) {
   return(unname(info))
 }
 
+#' @title generate start values for optimize
+#' @param tmp dataset
+#' @keywords internal
+generate_start_values <- function(tmp) {
+  nobs <- nrow(tmp)
+  nitems <- ncol(tmp)
+  ncat <- apply(tmp, 2, max, na.rm = TRUE)
 
-#' @title parameter transformation target_to_params
-#' @param target optimize target vector
-#' @param nitems number of items
-#' @param ncat number of categories for each items
-#' @keywords interenal
+  cor_mat <- cor(tmp, use = "pairwise.complete.obs")
+  diag(cor_mat) <- 1
+  eigen_result <- eigen(cor_mat)
+  loadings <- abs(eigen_result$vectors[, 1]) * sqrt(abs(eigen_result$values[1]))
+  a_init <- loadings / sqrt(1 - loadings^2)
+  a_init <- pmax(pmin(a_init, 2.5), 0.3)
 
-target_to_params_jac <- function(target, nitems, ncat) {
-  a_vec <- exp(target[1:nitems])
-  b_list <- vector("list", nitems)
-
-  pos <- nitems
+  b_init <- vector("list", nitems)
   for (j in 1:nitems) {
-    n_thresholds <- ncat[j] - 1
-
-    if (n_thresholds == 1) {
-      b_list[[j]] <- target[pos + 1]
+    valid_resp <- tmp[!is.na(tmp[, j]), j]
+    n_thresh <- ncat[j] - 1
+    if (n_thresh == 1) {
+      b_init[[j]] <- quantile(valid_resp, 0.5, na.rm = TRUE) - mean(valid_resp, na.rm = TRUE)
     } else {
-      first_threshold <- target[pos + 1]
-      deltas <- exp(target[(pos + 2):(pos + n_thresholds)])
-      b_list[[j]] <- c(first_threshold, first_threshold + cumsum(deltas))
+      probs <- seq(0.1, 0.9, length.out = n_thresh)
+      thresholds <- quantile(valid_resp, probs, na.rm = TRUE)
+      thresholds <- thresholds - median(thresholds)
+      thresholds <- sort(thresholds)
+      for (k in 2:length(thresholds)) {
+        if (thresholds[k] <= thresholds[k - 1]) {
+          thresholds[k] <- thresholds[k - 1] + 0.1
+        }
+      }
+      b_init[[j]] <- thresholds
     }
-
-    pos <- pos + n_thresholds
   }
-
-  return(list(a = a_vec, b = b_list))
+  return(list(a = a_init, b = b_init))
 }
 
-#' @title parameter transformation params_to_target
-#' @param a_vec vector of descriminant parameters
-#' @param b_list lists of difficuluty parameter vec
-#' @keywords internal
 
-params_to_target_jac <- function(a_vec, b_list) {
+#' @title convert parameters to optimization target
+#' @param a_vec discrimination parameter vector
+#' @param b_list threshold parameter list
+#' @keywords internal
+params_to_target <- function(a_vec, b_list) {
   nitems <- length(a_vec)
   target_a <- log(a_vec)
-
   target_b <- c()
-  target_b <- c()
-
   for (j in 1:nitems) {
     thresholds <- b_list[[j]]
     n_thresholds <- length(thresholds)
-
     if (n_thresholds == 1) {
       target_b <- c(target_b, thresholds)
     } else {
       target_b <- c(target_b, thresholds[1])
-
       for (k in 2:n_thresholds) {
-        delta <- thresholds[k] - thresholds[k - 1]
-        if (delta <= 0) delta <- 0.01
+        delta <- max(thresholds[k] - thresholds[k - 1], 0.01)
         target_b <- c(target_b, log(delta))
       }
     }
   }
-
   return(c(target_a, target_b))
 }
 
-#' @title Jacobian function for GRM
-#' @param target target vector
-#' @param nitems number of items
-#' @param ncat number of categories for each items
-#' @keywords internal
-Jacobian_grm <- function(target, nitems, ncat) {
-  jac_list <- vector("list", nitems)
-  pos <- nitems
-  for (j in 1:nitems) {
-    n_thresholds <- ncat[j] - 1
-    jac_matrix <- matrix(0, n_thresholds, n_thresholds)
-
-    if (n_thresholds == 1) {
-      jac_matrix[1, 1] <- 1
-    } else {
-      jac_matrix[1, 1] <- 1
-
-      for (i in 2:n_thresholds) {
-        jac_matrix[i, 1] <- 1
-        for (k in 2:i) {
-          jac_matrix[i, k] <- exp(target[pos + k])
-        }
-      }
-    }
-
-    a_jacobian <- exp(target[j])
-
-    jac_list[[j]] <- list(
-      a_jacobian = a_jacobian,
-      b_jacobian = jac_matrix
-    )
-
-    pos <- pos + n_thresholds
-  }
-
-  return(jac_list)
-}
-
-#' @title log_lik function for grm
-#' @param target target vector
-#' @param dat data set
-#' @keywords internal
-#'
-log_lik_grm <- function(target, dat, verbose) {
-  nobs <- NROW(dat)
-  nitems <- NCOL(dat)
-  ncat <- apply(dat, 2, max, na.rm = TRUE)
-  tmp <- target_to_params_jac(target, nitems, ncat)
-  a_vec <- tmp$a
-  b_list <- tmp$b
-
-  quadrature <- seq(-6, 6, length.out = 51)
-  weights <- dnorm(quadrature)
-  weights <- weights / sum(weights)
-  nq <- length(quadrature)
-
-  cum_pr_list <- list()
-  cat_pr_list <- list()
-
-  for (j in 1:nitems) {
-    ncats <- ncat[j]
-    cum_pr <- matrix(0, nrow = ncats + 1, ncol = nq)
-    cum_pr[1, ] <- 1
-    cum_pr[ncats + 1, ] <- 0
-    for (k in 1:length(b_list[[j]])) {
-      for (q in 1:nq) {
-        cum_pr[k + 1, q] <- 1 / (1 + exp(-a_vec[j] * (quadrature[q] - b_list[[j]][k])))
-      }
-    }
-
-    cat_pr <- matrix(0, nrow = ncats, ncol = nq)
-    for (k in 1:ncats) {
-      cat_pr[k, ] <- pmax(cum_pr[k, ] - cum_pr[k + 1, ], 1e-10)
-    }
-    cum_pr_list[[j]] <- cum_pr
-    cat_pr_list[[j]] <- cat_pr
-  }
-  ll <- 0
-  for (i in 1:nobs) {
-    log_p <- numeric(nq)
-    for (q in 1:nq) {
-      log_p_iq <- 0
-      for (j in 1:nitems) {
-        resp <- dat[i, j]
-        if (!is.na(resp)) {
-          log_p_iq <- log_p_iq + log(cat_pr_list[[j]][resp, q])
-        }
-      }
-      log_p[q] <- log_p_iq + log(weights[q])
-    }
-    log_p_max <- max(log_p)
-    ll <- ll + log_p_max + log(sum(exp(log_p - log_p_max)))
-  }
-  return(ll)
-}
-
-#' @title score function for grm
-#' @param target target vector
-#' @param dat data set
-#' @keywords internal
-#'
-score_function_with_Jacobian <- function(target, dat) {
-  nobs <- NROW(dat)
-  nitems <- NCOL(dat)
-  ncat <- apply(dat, 2, max, na.rm = T)
-
-  tmp <- target_to_params_jac(target, nitems, ncat)
-  a_vec <- tmp$a
-  b_list <- tmp$b
-
-  jacobians <- Jacobian_grm(target, nitems, ncat)
-  quadrature <- seq(-6, 6, length.out = 51)
-  weights <- dnorm(quadrature)
-  weights <- weights / sum(weights)
-  nq <- length(quadrature)
-
-  # prepare prob matrix size<PxQ>
-  cat_pr_list <- list()
-  cum_pr_list <- list()
-  prod_pr_list <- list()
-
-  for (j in 1:nitems) {
-    ncats <- ncat[j]
-    cum_pr <- matrix(0, nrow = ncats + 1, ncol = nq)
-    cum_pr[1, ] <- 1
-    cum_pr[ncats + 1, ] <- 0
-
-    for (k in 1:length(b_list[[j]])) {
-      for (q in 1:nq) {
-        cum_pr[k + 1, q] <- 1 / (1 + exp(-a_vec[j] * (quadrature[q] - b_list[[j]][k])))
-      }
-    }
-
-    cat_pr <- matrix(0, nrow = ncats, ncol = nq)
-    for (k in 1:ncats) {
-      cat_pr[k, ] <- pmax(cum_pr[k, ] - cum_pr[k + 1, ], 1e-10)
-    }
-
-    prod_pr <- cum_pr * (1 - cum_pr)
-
-    cum_pr_list[[j]] <- cum_pr
-    cat_pr_list[[j]] <- cat_pr
-    prod_pr_list[[j]] <- prod_pr
-  }
-
-  p_xz <- matrix(0, nobs, nq)
-  for (i in 1:nobs) {
-    for (q in 1:nq) {
-      log_lik_q <- 0
-      for (j in 1:nitems) {
-        resp <- dat[i, j]
-        if (!is.na(resp)) {
-          log_lik_q <- log_lik_q + log(cat_pr_list[[j]][resp, q])
-        }
-      }
-      p_xz[i, q] <- exp(log_lik_q)
-    }
-  }
-  # likelihood
-  p_x <- rowSums(p_xz * rep(weights, each = nobs))
-  # posterior distribution
-  p_z_x <- p_xz / p_x
-
-
-  model_score_a <- numeric(nitems)
-  model_score_b <- vector("list", nitems)
-  for (j in 1:nitems) {
-    model_score_b[[j]] <- numeric(length(b_list[[j]]))
-  }
-
-  for (i in 1:nobs) {
-    for (j in 1:nitems) {
-      resp <- dat[i, j]
-      if (!is.na(resp)) {
-        for (q in 1:nq) {
-          theta_q <- quadrature[q]
-          p_q <- p_z_x[i, q] * weights[q]
-
-          da_j <- 0
-          if (resp <= length(b_list[[j]])) {
-            gamma_k1 <- cum_pr_list[[j]][resp + 1, q]
-            prod_k1 <- prod_pr_list[[j]][resp + 1, q]
-            da_j <- da_j - (theta_q - b_list[[j]][resp]) * prod_k1 / cat_pr_list[[j]][resp, q]
-          }
-          if (resp > 1 && resp - 1 <= length(b_list[[j]])) {
-            gamma_k <- cum_pr_list[[j]][resp, q]
-            prod_k <- prod_pr_list[[j]][resp, q]
-            da_j <- da_j + (theta_q - b_list[[j]][resp - 1]) * prod_k / cat_pr_list[[j]][resp, q]
-          }
-          model_score_a[j] <- model_score_a[j] + p_q * da_j
-
-          for (k in 1:length(b_list[[j]])) {
-            db_jk <- 0
-            if (k == resp - 1 && resp > 0) {
-              prod_k <- prod_pr_list[[j]][resp, q]
-              db_jk <- db_jk + a_vec[j] * prod_k / cat_pr_list[[j]][resp, q]
-            }
-            if (k == resp && resp <= length(b_list[[j]])) {
-              prod_k1 <- prod_pr_list[[j]][resp + 1, q]
-              db_jk <- db_jk - a_vec[j] * prod_k1 / cat_pr_list[[j]][resp, q]
-            }
-            model_score_b[[j]][k] <- model_score_b[[j]][k] + p_q * db_jk
-          }
-        }
-      }
-    }
-  }
-
-  # set 0 for stability
-  for (j in 1:nitems) {
-    if (abs(model_score_a[j]) < 1e-8) model_score_a[j] <- 0
-    for (k in 1:length(model_score_b[[j]])) {
-      if (abs(model_score_b[[j]][k]) < 1e-8) model_score_b[[j]][k] <- 0
-    }
-  }
-
-  target_score <- numeric(length(target))
-  for (j in 1:nitems) {
-    target_score[j] <- -1 * model_score_a[j] * jacobians[[j]]$a_jacobian
-  }
-  pos <- nitems
-  for (j in 1:nitems) {
-    n_thresholds <- length(b_list[[j]])
-    target_grad_b <- as.vector(t(jacobians[[j]]$b_jacobian) %*% model_score_b[[j]])
-    target_score[(pos + 1):(pos + n_thresholds)] <- target_grad_b
-    pos <- pos + n_thresholds
-  }
-
-  return(-target_score)
-}
-
-#' @title generate start values for optimize
-#' @param tmp dataset
-#' @keywords internal
-
-generate_start_values <- function(tmp) {
-  nobs <- NROW(tmp$Z)
-  nitems <- NCOL(tmp$Q)
-  a <- numeric(nitems)
-  b <- vector("list", nitems)
-
-  cor <- PolychoricCorrelationMatrix(tmp)
-  eV <- eigen(cor)
-  loadings <- abs(eV$vectors[, 1]) * sqrt(eV$values[1])
-  a <- loadings / (1 - loadings^2)
-  a <- pmax(pmin(a, 2.5), 0.3)
-
-
-  for (j in 1:nitems) {
-    counts <- tabulate(tmp$Q[, j])
-    probs <- cumsum(counts / sum(counts))
-    thresholds <- qnorm(probs[-length(probs)])
-
-    thresholds <- pmax(pmin(thresholds, 4), -4)
-    for (k in 2:length(thresholds)) {
-      if (thresholds[k] <= thresholds[k - 1]) {
-        thresholds[k] <- thresholds[k - 1] + 0.1
-      }
-    }
-    b[[j]] <- thresholds
-  }
-  return(list(a = a, b = b))
-}
-
 #' @title Graded Response Model (GRM)
 #' @description
 #' Implements Samejima's (1969) Graded Response Model (GRM), which is an Item Response Theory
@@ -424,6 +161,8 @@ generate_start_values <- function(tmp) {
 #' \describe{
 #'   \item{testlength}{Length of the test (number of items)}
 #'   \item{nobs}{Sample size (number of rows in the dataset)}
+#'   \item{log_lik}{Log-likelihood value at convergence}
+#'   \item{iterations}{Number of iterations and function evaluations from optimization}
 #'   \item{params}{Matrix containing the estimated item parameters}
 #'   \item{EAP}{Ability parameters of examinees estimated by EAP method}
 #'   \item{MAP}{Ability parameters of examinees estimated by MAP method}
@@ -436,8 +175,9 @@ generate_start_values <- function(tmp) {
 #' Samejima, F. (1969). Estimation of latent ability using a response pattern of graded scores.
 #' Psychometrika Monograph Supplement, 34(4, Pt. 2), 1-100.
 #'
-#' @importFrom stats rnorm optim dnorm
-#' @importFrom graphics plot lines
+#' @importFrom stats optim dnorm
+#' @useDynLib exametrika, .registration=TRUE
+#' @importFrom Rcpp evalCpp
 #'
 #' @examples
 #' \donttest{
@@ -459,8 +199,8 @@ GRM <- function(U, na = NULL, Z = NULL, w = NULL, verbose = TRUE) {
     tmp <- U
   }
 
-  if (U$response.type != "ordinal") {
-    response_type_error(U$response.type, "GRM")
+  if (tmp$response.type != "ordinal") {
+    response_type_error(tmp$response.type, "GRM")
   }
 
   tmp$Q[tmp$Z == 0] <- NA
@@ -468,30 +208,32 @@ GRM <- function(U, na = NULL, Z = NULL, w = NULL, verbose = TRUE) {
   nitems <- NCOL(tmp$Z)
   nobs <- NROW(tmp$Z)
   ncat <- apply(dat, 2, function(x) max(x, na.rm = TRUE))
-  start_vals <- generate_start_values(tmp)
-  target <- target <- params_to_target_jac(start_vals$a, start_vals$b)
-  # item params
-  fit <- optim(
+  n_quad_points <- 51
+
+  start_vals <- generate_start_values(dat)
+  target <- params_to_target(start_vals$a, start_vals$b)
+  if (verbose) {
+    cat(
+      "Parameters:", length(target), "| Initial LL:",
+      round(log_lik_grm_cpp(target, dat, n_quad_points), 3), "\n"
+    )
+  }
+
+  result <- optim(
     par = target,
-    fn = log_lik_grm,
-    gr = score_function_with_Jacobian,
+    fn = function(x) -log_lik_grm_cpp(x, dat, n_quad_points),
+    gr = function(x) -score_function_analytical_grm(x, dat, n_quad_points),
     method = "BFGS",
     control = list(
-      maxit = 300,
-      reltol = 1e-16,
-      fnscale = -1,
+      maxit = 500,
+      reltol = 1e-8,
       trace = if (verbose) 1 else 0
-    ),
-    dat = tmp$Q
+    )
   )
+  final_params <- target_to_params_grm(result$par, nitems, ncat)
 
-
-  est_params <- target_to_params_jac(fit$par, nitems, ncat)
-  est_a <- esvalueest_a <- est_params$a
-  est_b <- lapply(1:nitems, function(i) {
-    est_params$b[[i]] * est_a[i]
-  })
-
+  est_a <- final_params$a
+  est_b <- final_params$b
   est_mat <- matrix(NA, nrow = nitems, ncol = max(ncat))
   est_mat[, 1] <- est_a
   for (j in 1:nitems) {
@@ -500,7 +242,6 @@ GRM <- function(U, na = NULL, Z = NULL, w = NULL, verbose = TRUE) {
   colnames(est_mat) <- c("Slope", paste0("Threshold", 1:(max(ncat) - 1)))
   rownames(est_mat) <- tmp$ItemLabel
 
-
   # subject params
   quadrature <- seq(-6, 6, 0.01)
   quad_weight <- dnorm(quadrature)
@@ -604,6 +345,8 @@ GRM <- function(U, na = NULL, Z = NULL, w = NULL, verbose = TRUE) {
   ret <- structure(list(
     testlength = nitems,
     nobs = nobs,
+    log_lik = -result$value,
+    iterations = result$counts,
     params = as.data.frame(est_mat),
     EAP = EAP,
     MAP = MAP,
